@@ -1,6 +1,7 @@
 use std::fmt::Display;
 
 use fast_image_resize as fr;
+use fast_image_resize::pixels::PixelType;
 use pyo3::exceptions;
 use pyo3::prelude::*;
 
@@ -17,22 +18,23 @@ macro_rules! into_non_zero {
     }};
 }
 
-pub(crate) fn pixel_type_from_u8(pixel_type: u8) -> fr::PixelType {
+pub(crate) fn pixel_type_from_u8(pixel_type: u8) -> PixelType {
     match pixel_type {
-        1 => fr::PixelType::U8x4,
-        2 => fr::PixelType::I32,
-        3 => fr::PixelType::F32,
-        4 => fr::PixelType::U8,
-        _ => fr::PixelType::U8x4,
+        1 => PixelType::U8,
+        2 => PixelType::I32,
+        3 => PixelType::F32,
+        4 => PixelType::U8x3,
+        5 => PixelType::U8x4,
+        6 => PixelType::U16x3,
+        _ => PixelType::U8x4,
     }
 }
 
 pub(crate) fn cpu_extensions_from_u8(extensions: u8) -> fr::CpuExtensions {
     match extensions {
         1 => fr::CpuExtensions::None,
-        2 => fr::CpuExtensions::Sse2,
-        3 => fr::CpuExtensions::Sse4_1,
-        4 => fr::CpuExtensions::Avx2,
+        2 => fr::CpuExtensions::Sse4_1,
+        3 => fr::CpuExtensions::Avx2,
         _ => Default::default(),
     }
 }
@@ -40,8 +42,7 @@ pub(crate) fn cpu_extensions_from_u8(extensions: u8) -> fr::CpuExtensions {
 pub(crate) fn cpu_extensions_to_u8(extensions: fr::CpuExtensions) -> u8 {
     match extensions {
         fr::CpuExtensions::None => 1,
-        fr::CpuExtensions::Sse2 => 2,
-        fr::CpuExtensions::Sse4_1 => 3,
-        fr::CpuExtensions::Avx2 => 4,
+        fr::CpuExtensions::Sse4_1 => 2,
+        fr::CpuExtensions::Avx2 => 3,
     }
 }
